import type { IPriorityQueue } from '@algorithm.ts/priority-queue';
import type { GomokuDirectionType } from './constant';
import type { IGomokuContext } from './types/context';
import type { IGomokuCountMap } from './types/count-map';
import type { IGomokuCandidateState, IGomokuPiece, IShapeScoreMap } from './types/misc';
import type { IGomokuState } from './types/state';
export interface IGomokuStateProps {
    context: IGomokuContext;
    scoreMap: IShapeScoreMap;
    countMap: IGomokuCountMap;
}
export declare class GomokuState implements IGomokuState {
    readonly NEXT_MOVER_BUFFER = 4;
    readonly context: Readonly<IGomokuContext>;
    readonly countMap: Readonly<IGomokuCountMap>;
    readonly scoreMap: Readonly<IShapeScoreMap>;
    protected readonly _candidateQueues: Array<IPriorityQueue<IGomokuCandidateState>>;
    protected readonly _candidateInqSets: Array<Array<Set<number>>>;
    protected readonly _candidateSet: Set<number>;
    protected readonly _candidateScores: number[][];
    protected readonly _candidateScoreDirMap: number[][][];
    protected readonly _candidateScoreExpired: number[];
    protected readonly _stateScores: number[];
    protected readonly _stateScoreDirMap: number[][][];
    protected readonly _countOfReachFinal: number[];
    protected readonly _countOfReachFinalDirMap: number[][][];
    constructor(props: IGomokuStateProps);
    init(pieces: ReadonlyArray<IGomokuPiece>): void;
    forward(posId: number): void;
    revert(posId: number): void;
    expand(nextPlayerId: number, candidates: IGomokuCandidateState[], minMultipleOfTopScore: number, MAX_SIZE?: number): number;
    topCandidate(nextPlayerId: number): IGomokuCandidateState | undefined;
    score(currentPlayer: number, scoreForPlayer: number): number;
    isWin(currentPlayer: number): boolean;
    isDraw(): boolean;
    isFinal(): boolean;
    protected _updateStateScore(posId: number): void;
    protected _expireCandidates(centerPosId: number): void;
    protected _reEvaluateAndEnqueueCandidate(posId: number): void;
    protected _reEvaluateCandidate(posId: number): void;
    protected _evaluateScoreInDirection(playerId: number, startPosId: number, dirType: GomokuDirectionType): {
        score: number;
        countOfReachFinal: number;
    };
    protected _temporaryForward(posId: number, playerId: number): void;
    protected _temporaryRevert(posId: number): void;
}
